PeCorA: PeCorA

View source: R/PeCorA.R

PeCorAR Documentation

PeCorA

Description

core function of PeCorA workflow

Usage

PeCorA(t)

Arguments

t

scaled data

Details

PeCorA function relies on linear model to assess whether the slope of a peptide’s change across treatment groups differs from the slope of all other peptides assigned to the same protein.

Value

dataframe output of PeCorA analysis containing values for proteins/peptides adj_pval for peptide interaction across condition and peptide groups.

Author(s)

Maria Dermit maria.dermit@qmul.ac.uk

Examples

## Not run: 
if(interactive()){
 disagree_peptides <- PeCorA (scaled_peptides)
 }

## End(Not run)

jessegmeyerlab/PeCorA documentation built on Oct. 12, 2024, 10:44 p.m.