PeCorA_plotting: PeCorA_plotting

PeCorA_plottingR Documentation

PeCorA_plotting

Description

plot PeCorA output

Usage

PeCorA_plotting(w, u, v)

Arguments

w

disagree peptides

u

selection of disagree peptides

v

scaled peptides

Details

This function generates boxplots for a given protein representing the peptides that are statistically different from the quantities of all the other peptides in green and all other peptides in grey.

Value

PeCorA plot

Author(s)

Maria Dermit maria.dermit@qmul.ac.uk

Examples

## Not run: 
if(interactive()){
 PeCorA_plotting_plot<-PeCorA_plotting(disagree_peptides,disagree_peptides[1,],scaled_peptides)
 }

## End(Not run)

jessegmeyerlab/PeCorA documentation built on Oct. 12, 2024, 10:44 p.m.