PeCorA_preprocessing: PeCorA_preprocessing

PeCorA_preprocessingR Documentation

PeCorA_preprocessing

Description

steps to pre-process data for PeCorA

Usage

PeCorA_preprocessing(t, area_column_name, threshold_to_filter, control_name)

Arguments

t

data in PeCorA format

area_column_name

column number with peak areas

threshold_to_filter

threshould value of peak areas to filter

control_name

control reference

Details

Peak areas are log transformed and scaled to center.After global scaling, each peptide scaling was performed to center each peptide relative to the mean of the control group’s peak area.

Value

dataframe output of pre-process data ready for PeCorA analalysis

Author(s)

Maria Dermit maria.dermit@qmul.ac.uk

Examples

## Not run: 
if(interactive()){
 scaled_peptides <- PeCorA_preprocessing(t,
                                         area_column_name=8,
                                         threshold_to_filter=100,
                                         control_name="cntrl")
 }

## End(Not run)

jessegmeyerlab/PeCorA documentation built on Oct. 12, 2024, 10:44 p.m.