| PeCorA | R Documentation |
core function of PeCorA workflow
PeCorA(t)
t |
scaled data |
PeCorA function relies on linear model to assess whether the slope of a peptide’s change across treatment groups differs from the slope of all other peptides assigned to the same protein.
dataframe output of PeCorA analysis containing values for proteins/peptides adj_pval for peptide interaction across condition and peptide groups.
Maria Dermit maria.dermit@qmul.ac.uk
## Not run:
if(interactive()){
disagree_peptides <- PeCorA (scaled_peptides)
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.