| PeCorA_plotting | R Documentation |
plot PeCorA output
PeCorA_plotting(w, u, v)
w |
disagree peptides |
u |
selection of disagree peptides |
v |
scaled peptides |
This function generates boxplots for a given protein representing the peptides that are statistically different from the quantities of all the other peptides in green and all other peptides in grey.
PeCorA plot
Maria Dermit maria.dermit@qmul.ac.uk
## Not run:
if(interactive()){
PeCorA_plotting_plot<-PeCorA_plotting(disagree_peptides,disagree_peptides[1,],scaled_peptides)
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.