| PeCorA_preprocessing | R Documentation |
steps to pre-process data for PeCorA
PeCorA_preprocessing(t, area_column_name, threshold_to_filter, control_name)
t |
data in PeCorA format |
area_column_name |
column number with peak areas |
threshold_to_filter |
threshould value of peak areas to filter |
control_name |
control reference |
Peak areas are log transformed and scaled to center.After global scaling, each peptide scaling was performed to center each peptide relative to the mean of the control group’s peak area.
dataframe output of pre-process data ready for PeCorA analalysis
Maria Dermit maria.dermit@qmul.ac.uk
## Not run:
if(interactive()){
scaled_peptides <- PeCorA_preprocessing(t,
area_column_name=8,
threshold_to_filter=100,
control_name="cntrl")
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.